@@ -14,18 +14,22 @@
 # 			Copyright © 2012 atzz
 # 			Licensed under CC-BY-SA
 #
-
-
-import sys
+#  Parts of the docstrings based on the Python 3.8.2 Documentation
+#  Licensed under the Python Software Foundation License Version 2.
+#  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
+#  Copyright © 2000 BeOpen.com . All rights reserved.
+#  Copyright © 1995-2000 Corporation for National Research Initiatives . All rights reserved.
+#  Copyright © 1991-1995 Stichting Mathematisch Centrum . All rights reserved.
+#
 
 from domdf_python_tools.utils import *
 from domdf_python_tools import paths, terminal, utils, doctools
 
-__all__ = ["paths", "terminal", "utils"]
+__all__ = ["paths", "terminal", "utils", "dates"]
 
 __author__ = "Dominic Davis-Foster"
 __copyright__ = "2014-2019 Dominic Davis-Foster"
 
-__license__ = "LGPL"
-__version__ = "0.1.20"
+__license__ = "LGPLv3+"
+__version__ = "0.2.1"
 __email__ = "dominic@davis-foster.co.uk"
